@@ -1241,8 +1241,8 @@ gda_data_model_get_command_text (GdaDataModel *model)
 gboolean
 gda_data_model_set_command_text (GdaDataModel *model, const gchar *txt)
 {
-	g_return_if_fail (GDA_IS_DATA_MODEL (model));
-	g_return_if_fail (txt != NULL);
+	g_return_val_if_fail (GDA_IS_DATA_MODEL (model), FALSE);
+	g_return_val_if_fail (txt != NULL, FALSE);
 	
 	if (GDA_DATA_MODEL_GET_IFACE (model)->i_set_command)
 		return (GDA_DATA_MODEL_GET_IFACE (model)->i_set_command) (model, txt, -1);
@@ -1284,7 +1284,7 @@ gda_data_model_get_command_type (GdaDataModel *model)
 gboolean
 gda_data_model_set_command_type (GdaDataModel *model, GdaCommandType type)
 {
-	g_return_if_fail (GDA_IS_DATA_MODEL (model));
+	g_return_val_if_fail (GDA_IS_DATA_MODEL (model), FALSE);
 	if (GDA_DATA_MODEL_GET_IFACE (model)->i_set_command)
 		return (GDA_DATA_MODEL_GET_IFACE (model)->i_set_command) (model, NULL, type);
 	else
@@ -1337,6 +1337,8 @@ gda_data_model_dump_as_string (GdaDataModel *model)
 
 	g_return_val_if_fail (GDA_IS_DATA_MODEL (model), NULL);
 
+	string = g_string_new ("");
+
         /* string for the offset */
         offstr = g_new0 (gchar, offset+1);
 	memset (offstr, ' ', offset);
@@ -1356,6 +1358,7 @@ gda_data_model_dump_as_string (GdaDataModel *model)
 
 		gdacol = gda_data_model_describe_column (model, i);
 		coltype = gda_column_get_gdatype (gdacol);
+		/*g_string_append_printf (string, "COL %d is a %s\n", i+1, gda_type_to_string (coltype));*/
 		if ((coltype == GDA_VALUE_TYPE_BIGINT) ||
 		    (coltype == GDA_VALUE_TYPE_BIGUINT) ||
 		    (coltype == GDA_VALUE_TYPE_INTEGER) ||
@@ -1382,7 +1385,6 @@ gda_data_model_dump_as_string (GdaDataModel *model)
 	}
 	
 	/* actual dumping of the contents: column titles...*/
-	string = g_string_new ("");
 	for (i = 0; i < n_cols; i++) {
 		gint j;
 		str = gda_data_model_get_column_title (model, i);
