@@ -117,7 +117,7 @@ run_export_cb (gpointer user_data)
 
 		cmd = gda_command_new (name, GDA_COMMAND_TYPE_TABLE, 0);
 
-		recset = gda_connection_execute_single_command (exp->priv->cnc, cmd, NULL);
+		recset = gda_connection_execute_single_command (exp->priv->cnc, cmd, NULL, NULL);
 		gda_command_free (cmd);
 		if (!GDA_IS_DATA_MODEL (recset)) {
 			gda_export_stop (exp);
@@ -213,10 +213,10 @@ gda_export_class_init (GdaExportClass *klass)
 			      G_TYPE_NONE, 2,
 			      G_TYPE_INT, G_TYPE_STRING);
 	gda_export_signals[CANCELLED] =
-		g_signal_new ("finished",
+		g_signal_new ("cancelled",
 				G_TYPE_FROM_CLASS (object_class),
 			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (GdaExportClass, finished),
+			      G_STRUCT_OFFSET (GdaExportClass, cancelled),
 			      NULL, NULL,
 			      g_cclosure_marshal_VOID__VOID,
 			      G_TYPE_NONE, 0);
@@ -294,7 +294,7 @@ gda_export_new (GdaConnection * cnc)
  * @exp: a #GdaExport object.
  *
  * Returns a list of all tables that exist in the #GdaConnection
- * being used by the given #GdaExport object.. This function is 
+ * being used by the given #GdaExport object. This function is 
  * useful when you're building, for example, a list for the user 
  * to select which tables he/she wants in the export process.
  *
