@@ -33,10 +33,16 @@ struct _GdaTablePrivate {
 	GHashTable *fields;
 };
 
+enum {
+	NAME_CHANGED,
+	LAST_SIGNAL
+};
+
 static void gda_table_class_init (GdaTableClass *klass);
 static void gda_table_init       (GdaTable *table, GdaTableClass *klass);
 static void gda_table_finalize   (GObject *object);
 
+static guint gda_table_signals[LAST_SIGNAL];
 static GObjectClass *parent_class = NULL;
 
 /*
@@ -46,26 +52,26 @@ static GObjectClass *parent_class = NULL;
 typedef struct {
 	GdaTable *table;
 	gint col_to_search;
-	GdaDataModelColumnAttributes *fa;
+	GdaColumn *column;
 } DescColData;
 
 static void
 search_field_in_hash (gpointer key, gpointer value, gpointer user_data)
 {
 	DescColData *cb_data = user_data;
-	GdaDataModelColumnAttributes *fa = value;
+	GdaColumn *column = value;
 
-	if (cb_data->fa)
+	if (cb_data->column)
 		return;
-	if (gda_data_model_column_attributes_get_position (fa) == cb_data->col_to_search)
-		cb_data->fa = fa;
+	if (gda_column_get_position (column) == cb_data->col_to_search)
+		cb_data->column = column;
 }
 
-static GdaDataModelColumnAttributes *
+static GdaColumn *
 gda_table_describe_column (GdaDataModelBase *model, gint col)
 {
 	DescColData cb_data;
-	GdaDataModelColumnAttributes *new_fa;
+	GdaColumn *new_column;
 	GdaTable *table = (GdaTable *) model;
 
 	g_return_val_if_fail (GDA_IS_TABLE (table), NULL);
@@ -75,13 +81,13 @@ gda_table_describe_column (GdaDataModelBase *model, gint col)
 
 	cb_data.table = table;
 	cb_data.col_to_search = col;
-	cb_data.fa = NULL;
+	cb_data.column = NULL;
 	g_hash_table_foreach (table->priv->fields, (GHFunc) search_field_in_hash, &cb_data);
-	if (!cb_data.fa)
+	if (!cb_data.column)
 		return NULL;
 
-	new_fa = gda_data_model_column_attributes_copy (cb_data.fa);
-	return new_fa;
+	new_column = gda_column_copy (cb_data.column);
+	return new_column;
 }
 
 static void
@@ -92,6 +98,15 @@ gda_table_class_init (GdaTableClass *klass)
 
 	parent_class = g_type_class_peek_parent (klass);
 
+	gda_table_signals[NAME_CHANGED] =
+		g_signal_new ("name_changed",
+			      G_TYPE_FROM_CLASS (object_class),
+			      G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (GdaTableClass, name_changed),
+			      NULL, NULL,
+			      g_cclosure_marshal_VOID__STRING,
+			      G_TYPE_NONE, 1, G_TYPE_STRING);
+
 	object_class->finalize = gda_table_finalize;
 	model_class->describe_column = gda_table_describe_column;
 }
@@ -111,7 +126,7 @@ static gboolean
 remove_field_hash (gpointer key, gpointer value, gpointer user_data)
 {
 	g_free (key);
-	gda_data_model_column_attributes_free (value);
+	gda_column_free (value);
 	return TRUE;
 }
 
@@ -215,11 +230,11 @@ gda_table_new_from_model (const gchar *name, const GdaDataModel *model, gboolean
 	/* add the columns description */
 	cols = gda_data_model_get_n_columns (GDA_DATA_MODEL (model));
 	for (n = 0; n < cols; n++) {
-		GdaDataModelColumnAttributes *fa;
+		GdaColumn *column;
 
-		fa = gda_data_model_describe_column (GDA_DATA_MODEL (model), n);
-		gda_table_add_field (table, (const GdaDataModelColumnAttributes *) fa);
-		gda_data_model_column_attributes_free (fa);
+		column = gda_data_model_describe_column (GDA_DATA_MODEL (model), n);
+		gda_table_add_field (table, (const GdaColumn *) column);
+		gda_column_free (column);
 	}
 
 	/* add the data */
@@ -252,32 +267,39 @@ gda_table_get_name (GdaTable *table)
 void
 gda_table_set_name (GdaTable *table, const gchar *name)
 {
+	gchar *old_name;
+	
 	g_return_if_fail (GDA_IS_TABLE (table));
 	g_return_if_fail (name != NULL);
 
+	old_name = g_strdup (table->priv->name);
 	if (table->priv->name)
 		g_free (table->priv->name);
 
 	table->priv->name = g_strdup (name);
+	g_signal_emit (G_OBJECT (table),
+		       gda_table_signals[NAME_CHANGED],
+		       0, old_name);
+	gda_data_model_changed (GDA_DATA_MODEL (table));
 }
 
 /**
  * gda_table_add_field
  * @table: a #GdaTable object.
- * @fa: attributes for the new field.
+ * @column: column attributes for the new field.
  *
  * Adds a field to the given #GdaTable.
  */
 void
-gda_table_add_field (GdaTable *table, const GdaDataModelColumnAttributes *fa)
+gda_table_add_field (GdaTable *table, const GdaColumn *column)
 {
 	const gchar *name;
-	GdaDataModelColumnAttributes *new_fa;
+	GdaColumn *new_column;
 
 	g_return_if_fail (GDA_IS_TABLE (table));
-	g_return_if_fail (fa != NULL);
+	g_return_if_fail (column != NULL);
 
-	name = gda_data_model_column_attributes_get_name ((GdaDataModelColumnAttributes *) fa);
+	name = gda_column_get_name ((GdaColumn *) column);
 	if (!name || !*name)
 		return;
 
@@ -288,16 +310,16 @@ gda_table_add_field (GdaTable *table, const GdaDataModelColumnAttributes *fa)
 	}
 
 	/* add the new field to the table */
-	new_fa = gda_data_model_column_attributes_new ();
-	gda_data_model_column_attributes_set_table (new_fa, table->priv->name);
-	gda_data_model_column_attributes_set_position (new_fa, g_hash_table_size (table->priv->fields));
-	gda_data_model_column_attributes_set_defined_size (new_fa, gda_data_model_column_attributes_get_defined_size ((GdaDataModelColumnAttributes *) fa));
-	gda_data_model_column_attributes_set_name (new_fa, name);
-	gda_data_model_column_attributes_set_scale (new_fa, gda_data_model_column_attributes_get_scale ((GdaDataModelColumnAttributes *) fa));
-	gda_data_model_column_attributes_set_gdatype (new_fa, gda_data_model_column_attributes_get_gdatype ((GdaDataModelColumnAttributes *) fa));
-	gda_data_model_column_attributes_set_allow_null (new_fa, gda_data_model_column_attributes_get_allow_null ((GdaDataModelColumnAttributes *) fa));
+	new_column = gda_column_new ();
+	gda_column_set_table (new_column, table->priv->name);
+	gda_column_set_position (new_column, g_hash_table_size (table->priv->fields));
+	gda_column_set_defined_size (new_column, gda_column_get_defined_size ((GdaColumn *) column));
+	gda_column_set_name (new_column, name);
+	gda_column_set_scale (new_column, gda_column_get_scale ((GdaColumn *) column));
+	gda_column_set_gdatype (new_column, gda_column_get_gdatype ((GdaColumn *) column));
+	gda_column_set_allow_null (new_column, gda_column_get_allow_null ((GdaColumn *) column));
 
-	g_hash_table_insert (table->priv->fields, g_strdup (name), new_fa);
+	g_hash_table_insert (table->priv->fields, g_strdup (name), new_column);
 	gda_data_model_array_set_n_columns (GDA_DATA_MODEL_ARRAY (table),
 					    g_hash_table_size (table->priv->fields));
 }
@@ -317,3 +339,54 @@ gda_table_add_data_from_model (GdaTable *table, const GdaDataModel *model)
 
     /* FIXME: implement me */
 }
+
+static void
+add_field_to_list (gpointer key, gpointer value, gpointer user_data)
+{
+	gchar *name = (gchar *) key;
+	GList **list = (GList **) user_data;
+
+	*list = g_list_append (*list, g_strdup (name));
+}
+
+gint
+compare_columns_func (const gchar *cname_a, const gchar *cname_b, GdaTable *table)
+{
+	GdaColumn *ca_a, *ca_b;
+	gint pos_a, pos_b;
+	
+	ca_a = gda_table_find_column (table, cname_a);
+	ca_b = gda_table_find_column (table, cname_b);
+	
+	pos_a = gda_column_get_position (ca_a);
+	pos_b = gda_column_get_position (ca_b);
+
+	if (pos_a < pos_b) {
+		return -1;
+	} else if (pos_a > pos_b) {
+		return 1;
+	} else {
+		return 0;
+	}
+}
+
+GList *
+gda_table_get_columns (GdaTable *table)
+{
+	GList *list = NULL;
+	
+	g_return_val_if_fail (GDA_IS_TABLE (table), NULL);
+	
+	g_hash_table_foreach (table->priv->fields, (GHFunc) add_field_to_list, &list);
+	list = g_list_sort_with_data (list, compare_columns_func, table);
+	return list;
+}
+
+GdaColumn *
+gda_table_find_column (GdaTable *table, const gchar *name)
+{
+	g_return_val_if_fail (GDA_IS_TABLE (table), NULL);
+	g_return_val_if_fail (name != NULL, NULL);
+	
+	return g_hash_table_lookup (table->priv->fields, name);
+}
