@@ -29,7 +29,7 @@ gda_mdb_table_new (GdaMdbConnection *mdb_cnc, const gchar *name)
 	MdbCatalogEntry *entry;
 	MdbTableDef *mdb_table;
 	MdbColumn *mdb_col;
-	GdaDataModelColumnAttributes *fa;
+	GdaColumn *fa;
 	GdaTable *table = NULL;
 
 	g_return_val_if_fail (mdb_cnc != NULL, NULL);
@@ -45,7 +45,7 @@ gda_mdb_table_new (GdaMdbConnection *mdb_cnc, const gchar *name)
 	}
 
 	if (!entry) {
-		gda_connection_add_error_string (mdb_cnc->cnc, _("Table %s not found"), name);
+		gda_connection_add_event_string (mdb_cnc->cnc, _("Table %s not found"), name);
 		return NULL;
 	}
 
@@ -58,14 +58,14 @@ gda_mdb_table_new (GdaMdbConnection *mdb_cnc, const gchar *name)
 	for (i = 0; i < mdb_table->num_cols; i++) {
 		mdb_col = g_ptr_array_index (mdb_table->columns, i);
 
-		fa = gda_data_model_column_attributes_new ();
-		gda_data_model_column_attributes_set_name (fa, mdb_col->name);
-		gda_data_model_column_attributes_set_gdatype (fa, gda_mdb_type_to_gda (mdb_col->col_type));
-		gda_data_model_column_attributes_set_defined_size (fa, mdb_col->col_size);
+		fa = gda_column_new ();
+		gda_column_set_name (fa, mdb_col->name);
+		gda_column_set_gdatype (fa, gda_mdb_type_to_gda (mdb_col->col_type));
+		gda_column_set_defined_size (fa, mdb_col->col_size);
 
-		gda_table_add_field (table, (const GdaDataModelColumnAttributes *) fa);
+		gda_table_add_field (table, (const GdaColumn *) fa);
 
-		gda_data_model_column_attributes_free (fa);
+		gda_column_free (fa);
 	}
 
 	return table;
