@@ -1,5 +1,5 @@
 /* GDA mSQL Provider
- * Copyright (C) 1998-2002 The GNOME Foundation
+ * Copyright (C) 1998 - 2005 The GNOME Foundation
  *
  * AUTHORS:
  * 	   Danilo Schoeneberg <dj@starfire-programming.net
@@ -50,8 +50,8 @@ static const gchar *gda_msql_provider_get_database(GdaServerProvider*,
                                                    GdaConnection*);
 static gboolean gda_msql_provider_change_database(GdaServerProvider*,
                                                   GdaConnection*,const gchar*);
-static gboolean gda_msql_provider_create_database(GdaServerProvider*,
-                                                  GdaConnection*,const gchar*);
+static gboolean gda_msql_provider_create_database_cnc(GdaServerProvider*,
+                                                      GdaConnection*,const gchar*);
 static gboolean gda_msql_provider_drop_database(GdaServerProvider*,
                                                 GdaConnection*,const gchar*);
 static GList *gda_msql_provider_execute_command(GdaServerProvider*,
@@ -94,7 +94,7 @@ static void gda_msql_provider_class_init(GdaMsqlProviderClass *cl)
 	pcl->get_server_version=gda_msql_provider_get_server_version;
 	pcl->get_database=gda_msql_provider_get_database;
 	pcl->change_database=gda_msql_provider_change_database;
-	pcl->create_database=gda_msql_provider_create_database;
+	pcl->create_database_cnc=gda_msql_provider_create_database_cnc;
 	pcl->drop_database=gda_msql_provider_drop_database;
 	pcl->execute_command=gda_msql_provider_execute_command;
 	pcl->begin_transaction=gda_msql_provider_begin_transaction;
@@ -163,7 +163,7 @@ static gboolean gda_msql_provider_open_connection(GdaServerProvider *p1,
 {
 	const gchar *_host = NULL;
 	const gchar *_db = NULL;
-	GdaError *error;
+	GdaConnectionEvent *error;
 	int rc=-1,sock=-1;
 	gint *sock_ptr;
 	GdaMsqlProvider *p=(GdaMsqlProvider*)p1;
@@ -176,13 +176,13 @@ static gboolean gda_msql_provider_open_connection(GdaServerProvider *p1,
 	sock=msqlConnect((char*)_host);
 	if (sock<0) {
 		error=gda_msql_make_error(sock);
-		gda_connection_add_error(cnc,error);
+		gda_connection_add_event(cnc,error);
 		return FALSE;
 	}
 	rc=msqlSelectDB(sock,(char*)_db);
 	if (rc<0) {
 		error=gda_msql_make_error(rc);
-		if (cnc) gda_connection_add_error(cnc,error);
+		if (cnc) gda_connection_add_event(cnc,error);
 		msqlClose(sock);
 		return FALSE;
 	}
@@ -239,7 +239,7 @@ static GList *process_sql_commands(GList *rl,GdaConnection *cnc,
 
 	sock=g_object_get_data(G_OBJECT(cnc),OBJECT_DATA_MSQL_HANDLE);
 	if ((!sock) || (*sock<0)) {
-		gda_connection_add_error_string(cnc,_("Invalid mSQL handle"));
+		gda_connection_add_event_string(cnc,_("Invalid mSQL handle"));
 		return NULL;
 	}
 	options=gda_connection_get_options(cnc);
@@ -254,7 +254,7 @@ static GList *process_sql_commands(GList *rl,GdaConnection *cnc,
 
 			rc=msqlQuery(*sock,arr[n]);
 			if (rc<0) {
-				gda_connection_add_error(cnc,gda_msql_make_error(rc));
+				gda_connection_add_event(cnc,gda_msql_make_error(rc));
 				break;
 			}
 			res=msqlStoreResult();
@@ -283,7 +283,7 @@ gda_msql_provider_get_database(GdaServerProvider *p,GdaConnection *cnc)
 	if (!GDA_IS_CONNECTION(cnc)) return NULL;
 	sock=g_object_get_data(G_OBJECT(cnc),OBJECT_DATA_MSQL_HANDLE);
 	if ((!sock) || (*sock<0)) {
-		gda_connection_add_error_string(cnc,_("Invalid mSQL handle"));
+		gda_connection_add_event_string(cnc,_("Invalid mSQL handle"));
 		return NULL;
 	}
 	dbname=g_object_get_data(G_OBJECT(cnc),OBJECT_DATA_MSQL_DBNAME);
@@ -304,7 +304,7 @@ gda_msql_provider_change_database(GdaServerProvider *p,GdaConnection *cnc,
 	if (!GDA_IS_CONNECTION(cnc)) return FALSE;
 	sock=g_object_get_data(G_OBJECT(cnc),OBJECT_DATA_MSQL_HANDLE);
 	if ((!sock) || (*sock<0)) {
-		gda_connection_add_error_string(cnc,_("Invalid mSQL handle"));
+		gda_connection_add_event_string(cnc,_("Invalid mSQL handle"));
 		return FALSE;
 	}
 	dbname=g_object_get_data(G_OBJECT(cnc),OBJECT_DATA_MSQL_DBNAME);
@@ -312,7 +312,7 @@ gda_msql_provider_change_database(GdaServerProvider *p,GdaConnection *cnc,
 	if (!name) return FALSE;
 	rc=msqlSelectDB(*sock,(char*)name);
 	if (rc<0) {
-		gda_connection_add_error(cnc,gda_msql_make_error(rc));
+		gda_connection_add_event(cnc,gda_msql_make_error(rc));
 		return FALSE;
 	}
 	g_free(dbname);  
@@ -321,15 +321,15 @@ gda_msql_provider_change_database(GdaServerProvider *p,GdaConnection *cnc,
 }
 
 static gboolean
-gda_msql_provider_create_database(GdaServerProvider *p,
-                                  GdaConnection *cnc,
-                                  const gchar *name)
+gda_msql_provider_create_database_cnc(GdaServerProvider *p,
+                                      GdaConnection *cnc,
+                                      const gchar *name)
 {
 	GdaMsqlProvider *mp=(GdaMsqlProvider*)p;
 
 	if (!GDA_IS_MSQL_PROVIDER(mp)) return FALSE;
 	if (!GDA_IS_CONNECTION(cnc)) return FALSE;
-	gda_connection_add_error_string(cnc,
+	gda_connection_add_event_string(cnc,
 					_("mSQL allows database creation only through the msqladmin tool."));
 	return FALSE;
 }
@@ -343,7 +343,7 @@ gda_msql_provider_drop_database(GdaServerProvider *p,
 
 	if (!GDA_IS_MSQL_PROVIDER(mp)) return FALSE;
 	if (!GDA_IS_CONNECTION(cnc)) return FALSE;
-	gda_connection_add_error_string(cnc,
+	gda_connection_add_event_string(cnc,
 					_("mSQL allows database drops only through the msqladmin tool."));
 	return FALSE;
 }
@@ -390,7 +390,7 @@ gda_msql_provider_begin_transaction(GdaServerProvider *p,
 
 	if (!GDA_IS_MSQL_PROVIDER(mp)) return FALSE;
 	if (!GDA_IS_CONNECTION(cnc)) return FALSE;
-	gda_connection_add_error_string(cnc,
+	gda_connection_add_event_string(cnc,
 					_("mSQL doesn't support transactions."));
 	return FALSE;
 }
@@ -404,7 +404,7 @@ gda_msql_provider_commit_transaction(GdaServerProvider *p,
 
 	if (!GDA_IS_MSQL_PROVIDER(mp)) return FALSE;
 	if (!GDA_IS_CONNECTION(cnc)) return FALSE;
-	gda_connection_add_error_string(cnc,
+	gda_connection_add_event_string(cnc,
 					_("mSQL doesn't support transactions."));
 	return FALSE;
 }
@@ -418,7 +418,7 @@ gda_msql_provider_rollback_transaction(GdaServerProvider *p,
 
 	if (!GDA_IS_MSQL_PROVIDER(mp)) return FALSE;
 	if (!GDA_IS_CONNECTION(cnc)) return FALSE;
-	gda_connection_add_error_string(cnc,
+	gda_connection_add_event_string(cnc,
 					_("mSQL doesn't support transactions."));
 	return FALSE;
 }
@@ -479,7 +479,7 @@ get_msql_tables(GdaConnection *cnc,GdaParameterList *params)
 		vlist=g_list_append(vlist,gda_value_new_string("n/a"));
 		vlist=g_list_append(vlist,gda_value_new_string("n/a"));
 		vlist=g_list_append(vlist,gda_value_new_string("n/a"));
-		gda_data_model_append_row(GDA_DATA_MODEL(model),vlist);
+		gda_data_model_append_values(GDA_DATA_MODEL(model),vlist);
 	}
 	msqlFreeResult(res);
 	return GDA_DATA_MODEL(model);    
@@ -518,8 +518,8 @@ get_msql_types(GdaConnection *cnc,GdaParameterList *params)
 		value_list=g_list_append(value_list,gda_value_new_string(types[i].name));
 		value_list=g_list_append(value_list,gda_value_new_string(types[i].owner));
 		value_list=g_list_append(value_list,gda_value_new_string(types[i].comments));
-		value_list=g_list_append(value_list,gda_value_new_type(types[i].type));  
-		gda_data_model_append_row(GDA_DATA_MODEL(rs),value_list);
+		value_list=g_list_append(value_list,gda_value_new_gdatype(types[i].type));  
+		gda_data_model_append_values(GDA_DATA_MODEL(rs),value_list);
 		g_list_foreach(value_list,(GFunc)gda_value_free,NULL);
 		g_list_free(value_list);
 	}
@@ -575,24 +575,24 @@ get_table_fields(GdaConnection *cnc,GdaParameterList *params)
 	g_return_val_if_fail(GDA_IS_CONNECTION(cnc),NULL);
 	g_return_val_if_fail(params!=NULL,NULL);
 	if ((!sock) || (*sock<0)) {
-		gda_connection_add_error_string(cnc,_("Invalid mSQL handle"));
+		gda_connection_add_event_string(cnc,_("Invalid mSQL handle"));
 		return NULL;
 	}
 	par=gda_parameter_list_find(params,"name");
 	if (!par) {
-		gda_connection_add_error_string(cnc,
+		gda_connection_add_event_string(cnc,
 						_("Table name is needed but none specified in parameter list"));
 		return NULL;
 	}
 	table_name=gda_value_get_string((GdaValue*)gda_parameter_get_value(par));
 	if (!table_name) {
-		gda_connection_add_error_string(cnc,
+		gda_connection_add_event_string(cnc,
 						_("Table name is needed but none specified in parameter list"));
 		return NULL;
 	}
 	res=msqlListFields(*sock,(char*)table_name);
 	if (!res) {
-		gda_connection_add_error(cnc,gda_msql_make_error(*sock));
+		gda_connection_add_event(cnc,gda_msql_make_error(*sock));
 		return NULL;
 	}
 	rs=(GdaDataModelArray*)gda_data_model_array_new(9);
@@ -611,7 +611,7 @@ get_table_fields(GdaConnection *cnc,GdaParameterList *params)
 			g_object_unref(G_OBJECT(rs));
 			return NULL;
 		}
-		gda_data_model_append_row(GDA_DATA_MODEL(rs),(const GList*)value_list);
+		gda_data_model_append_values(GDA_DATA_MODEL(rs),(const GList*)value_list);
 		g_list_foreach(value_list,(GFunc)gda_value_free,NULL);
 		g_list_free(value_list);
 	}
