@@ -25,23 +25,23 @@
 
 #include "gda-mysql.h"
 
-GdaError *
+GdaConnectionEvent *
 gda_mysql_make_error (MYSQL *handle)
 {
-	GdaError *error;
+	GdaConnectionEvent *error;
 
-	error = gda_error_new ();
+	error = gda_connection_event_new (GDA_CONNECTION_EVENT_ERROR);
 	if (handle != NULL) {
-		gda_error_set_description (error, mysql_error (handle));
-		gda_error_set_number (error, mysql_errno (handle));
+		gda_connection_event_set_description (error, mysql_error (handle));
+		gda_connection_event_set_code (error, mysql_errno (handle));
 	}
 	else {
-		gda_error_set_description (error, "NO DESCRIPTION");
-		gda_error_set_number (error, -1);
+		gda_connection_event_set_description (error, "NO DESCRIPTION");
+		gda_connection_event_set_code (error, -1);
 	}
 
-	gda_error_set_source (error, "gda-mysql");
-	gda_error_set_sqlstate (error, "Not available");
+	gda_connection_event_set_source (error, "gda-mysql");
+	gda_connection_event_set_sqlstate (error, "Not available");
 
 	return error;
 }
