@@ -1,5 +1,5 @@
 /* GDA Oracle provider
- * Copyright (C) 2002 The GNOME Foundation.
+ * Copyright (C) 2002 - 2005 The GNOME Foundation.
  *
  * AUTHORS:
  * 	Tim Coleman <tim@timcoleman.com>
@@ -43,15 +43,15 @@
  *
  * The error number is set to the Oracle error code.
  */
-GdaError *
+GdaConnectionEvent *
 gda_oracle_make_error (dvoid *hndlp, ub4 type, const gchar *file, gint line)
 {
-	GdaError *error;
+	GdaConnectionEvent *error;
 	gchar errbuf[512];
 	ub4 errcode;
 	gchar *source;
 
-	error = gda_error_new ();
+	error = gda_connection_event_new (GDA_CONNECTION_EVENT_ERROR);
 
 	if (hndlp != NULL) {
 		OCIErrorGet ((dvoid *) hndlp,
@@ -62,16 +62,16 @@ gda_oracle_make_error (dvoid *hndlp, ub4 type, const gchar *file, gint line)
 				(ub4) sizeof (errbuf), 
 				(ub4) type);
 	
-		gda_error_set_description (error, errbuf);	
+		gda_connection_event_set_description (error, errbuf);	
 	} else {
-		gda_error_set_description (error, _("NO DESCRIPTION"));
+		gda_connection_event_set_description (error, _("NO DESCRIPTION"));
 	}
 		
-	gda_error_set_number (error, errcode);
+	gda_connection_event_set_code (error, errcode);
 	source = g_strdup_printf("gda-oracle:%s:%d", file, line);
-	gda_error_set_source (error, source);
+	gda_connection_event_set_source (error, source);
 	g_free(source);
-	gda_error_set_sqlstate (error, _("Not available"));
+	gda_connection_event_set_sqlstate (error, _("Not available"));
 	
 	return error;
 }
@@ -106,15 +106,15 @@ gda_oracle_handle_error(gint result, GdaConnection *cnc,
 	case OCI_ERROR:
 		switch(type) {
 		case OCI_HTYPE_ERROR:
-			gda_connection_add_error (cnc, gda_oracle_make_error (priv_data->herr, type, file, line));
+			gda_connection_add_event (cnc, gda_oracle_make_error (priv_data->herr, type, file, line));
 			break;
 		case OCI_HTYPE_ENV:
-			gda_connection_add_error (cnc, gda_oracle_make_error (priv_data->henv, type, file, line));
-		default:
+			gda_connection_add_event (cnc, gda_oracle_make_error (priv_data->henv, type, file, line));
+		default: ;
 		}
 		break;
 	default:
-		gda_connection_add_error_string (cnc, msg);
+		gda_connection_add_event_string (cnc, msg);
 	}
 	return FALSE;
 }
@@ -286,7 +286,7 @@ gda_oracle_value_to_sql_string (GdaValue *value)
 	if (!val_str)
 		return NULL;
 
-	switch (value->type) {
+	switch (gda_value_get_type (value)) {
 	case GDA_VALUE_TYPE_BIGINT :
 	case GDA_VALUE_TYPE_DOUBLE :
 	case GDA_VALUE_TYPE_INTEGER :
@@ -320,7 +320,7 @@ gda_value_to_oracle_value (const GdaValue *value)
 
 	ora_value = g_new0 (GdaOracleValue, 1);
 
-	ora_value->gda_type = value->type;
+	ora_value->gda_type = gda_value_get_type (value);
 	ora_value->indicator = 0;
 	ora_value->hdef = (OCIDefine *) 0;
 	ora_value->pard = (OCIParam *) 0;
@@ -392,7 +392,7 @@ gda_oracle_set_value (GdaValue *value,
 	ub1 min;
 	ub1 sec;
 
-	gchar *string_buffer;
+	gchar *string_buffer, *tmp;
 
 	if (-1 == (ora_value->indicator)) {
 		gda_value_set_null (value);
@@ -408,7 +408,10 @@ gda_oracle_set_value (GdaValue *value,
 		memcpy (string_buffer, ora_value->value, ora_value->defined_size);
 		string_buffer[ora_value->defined_size] = '\0';
 		g_strchomp(string_buffer);
-		gda_value_set_string (value, string_buffer);
+		tmp = g_locale_to_utf8 (string_buffer, -1, NULL, NULL, NULL);
+		gda_value_set_string (value, tmp);
+		g_free (tmp);
+		g_free (string_buffer);
 		break;
 	case GDA_VALUE_TYPE_BIGINT:
 		gda_value_set_bigint (value, atoll (ora_value->value));
@@ -426,10 +429,15 @@ gda_oracle_set_value (GdaValue *value,
 		gda_value_set_double (value, atof (ora_value->value));
 		break;
 	case GDA_VALUE_TYPE_NUMERIC:
-		numeric.number = ora_value->value;
-		numeric.precision = 5; /* FIXME */
-		numeric.width = 5; /* FIXME */
+		string_buffer = g_malloc0 (ora_value->defined_size+1);
+		memcpy (string_buffer, ora_value->value, ora_value->defined_size);
+		string_buffer [ora_value->defined_size] = '\0';
+		g_strchomp (string_buffer);
+		numeric.number = string_buffer;
+		numeric.precision = 0; /* FIXME */
+		numeric.width = 0; /* FIXME */
 		gda_value_set_numeric (value, &numeric);
+		g_free (string_buffer);
 		break;
 	case GDA_VALUE_TYPE_DATE:
 		OCIDateGetDate ((CONST OCIDate *) ora_value->value,
