@@ -16,7 +16,7 @@
 ** sqliteRegisterBuildinFunctions() found at the bottom of the file.
 ** All other code has file scope.
 **
-** $Id: func.c,v 1.2 2005/05/15 16:50:14 vivien Exp $
+** $Id: func.c,v 1.3 2005/08/06 12:52:19 vivien Exp $
 */
 #include "sqliteInt.h"
 #include <ctype.h>
@@ -1035,4 +1035,9 @@ void sqlite3RegisterBuiltinFunctions(sqlite3 *db){
     }
   }
   sqlite3RegisterDateTimeFunctions(db);
+#ifdef SQLITE_SSE
+  {
+    sqlite3SseFunctions(db);
+  }
+#endif
 }
