@@ -290,7 +290,7 @@ gda_sybase_process_row_result (GdaConnection           *cnc,
 	GdaSybaseRecordset *srecset = NULL;
 	GdaSybaseField     *sfield = NULL;
 	GdaRow             *row = NULL;
-	GdaError           *error = NULL;
+	GdaConnectionEvent           *error = NULL;
 	gboolean           columns_set = FALSE;
 	gboolean           sfields_allocated = TRUE;
 	gint               i = 0;
@@ -308,7 +308,7 @@ gda_sybase_process_row_result (GdaConnection           *cnc,
 		srecset->priv->scnc = scnc;
 	} else {
 		// most probably a lack of ram failure, 
-		// so don't alloc e.g. an instance of GdaError
+		// so don't alloc e.g. an instance of GdaConnectionEvent
 		if (srecset) {
 			g_object_unref (srecset);
 			srecset = NULL;
@@ -331,7 +331,7 @@ gda_sybase_process_row_result (GdaConnection           *cnc,
 		error = gda_sybase_make_error (scnc,
 		                               _("%s failed while processing a row result."),
 		                               "ct_res_info()");
-		gda_connection_add_error (cnc, error);
+		gda_connection_add_event (cnc, error);
 		sybase_check_messages(cnc);
 		return NULL;
 	}
@@ -339,7 +339,7 @@ gda_sybase_process_row_result (GdaConnection           *cnc,
 		error = gda_sybase_make_error (scnc,
 		                               _("%s returned <= 0 columns."),
 		                               "ct_res_info()");
-		gda_connection_add_error (cnc, error);
+		gda_connection_add_event (cnc, error);
 		return NULL;
 	}
 
@@ -381,7 +381,7 @@ gda_sybase_process_row_result (GdaConnection           *cnc,
 		if (scnc->ret != CS_SUCCEED) {
 			error = gda_sybase_make_error (scnc, 
 			                               _("Could not run %s on column %d"), "ct_describe()", i);
-			gda_connection_add_error (cnc, error);
+			gda_connection_add_event (cnc, error);
 			sybase_check_messages(cnc);
 			break;
 		}
@@ -390,7 +390,7 @@ gda_sybase_process_row_result (GdaConnection           *cnc,
 		if (sfield->data == NULL) {
 			error = gda_sybase_make_error (scnc,
 			                               _("Could not allocate data placeholder for column %d"), i);
-			gda_connection_add_error (cnc, error);
+			gda_connection_add_event (cnc, error);
 			sybase_check_messages(cnc);
 			break;
 		}
@@ -402,7 +402,7 @@ gda_sybase_process_row_result (GdaConnection           *cnc,
 		if (scnc->ret != CS_SUCCEED) {
 			error = gda_sybase_make_error (scnc,
 			                               _("Could not run %s on column %d"), "ct_bind()", i);
-			gda_connection_add_error (cnc, error);
+			gda_connection_add_event (cnc, error);
 			sybase_check_messages(cnc);
 			break;
 		}
@@ -421,7 +421,7 @@ gda_sybase_process_row_result (GdaConnection           *cnc,
 		scnc->ret = ct_cancel (NULL, scnc->cmd, CS_CANCEL_ALL);
 		if (scnc->ret != CS_SUCCEED) {
 			error = gda_sybase_make_error (scnc, _("Could not run %s to cancel processing row resultset."), "ct_cancel");
-			gda_connection_add_error (cnc, error);
+			gda_connection_add_event (cnc, error);
 			sybase_check_messages(cnc);
 		}
 		
@@ -437,7 +437,7 @@ gda_sybase_process_row_result (GdaConnection           *cnc,
 		
 		if (scnc->ret == CS_ROW_FAIL) {
 			error = gda_sybase_make_error (scnc, _("%s failed on row %d"), "ct_fetch()", row_cnt);
-			gda_connection_add_error (cnc, error);
+			gda_connection_add_event (cnc, error);
 			sybase_check_messages(cnc);
 		}
 		
@@ -464,7 +464,7 @@ gda_sybase_process_row_result (GdaConnection           *cnc,
 			break;
 		default:
 			error = gda_sybase_make_error (scnc, _("%s terminated with unexpected return code."), "ct_fetch()");
-			gda_connection_add_error (cnc, error);
+			gda_connection_add_event (cnc, error);
 			sybase_check_messages(cnc);
 	}
 	
@@ -473,8 +473,8 @@ gda_sybase_process_row_result (GdaConnection           *cnc,
 
 
 GdaSybaseRecordset *
-gda_sybase_process_msg_result(GdaConnection *cnc,
-															GdaSybaseConnectionData *scnc)
+gda_sybase_process_msg_result (GdaConnection *cnc,
+			       GdaSybaseConnectionData *scnc)
 {
 	
 	// in ASE when a stored procedure uses the print statement, it 
@@ -487,7 +487,7 @@ gda_sybase_process_msg_result(GdaConnection *cnc,
 	GdaValue *val = NULL;
 	gchar *message;
 	CS_INT msgcnt = 0;
-	GdaError *error;
+	GdaConnectionEvent *error;
 	CS_SERVERMSG msg; 
 	CS_RETCODE ret;
 
@@ -505,13 +505,13 @@ gda_sybase_process_msg_result(GdaConnection *cnc,
 								 &msgcnt);
 	
 	if ( ret != CS_SUCCEED ) {
-		error = gda_error_new();
+		error = gda_connection_event_new();
 		g_return_val_if_fail (error != NULL, FALSE);
-		gda_error_set_description (error, _("an error occured when calling ct_diag attempting to retrieve a server message count for resultset"));
-		gda_error_set_number (error, -1);
-		gda_error_set_source (error, "gda-sybase");
-		gda_error_set_sqlstate (error, _("Not available"));					
-		gda_connection_add_error (cnc, error);		
+		gda_connection_event_set_description (error, _("An error occured when attempting to retrieve a server message count for resultset"));
+		gda_connection_event_set_code (error, -1);
+		gda_connection_event_set_source (error, "gda-sybase");
+		gda_connection_event_set_sqlstate (error, _("Not available"));					
+		gda_connection_add_event (cnc, error);		
 		return NULL;
 	}
 
@@ -526,14 +526,15 @@ gda_sybase_process_msg_result(GdaConnection *cnc,
 																1, 
 																&msg); 
 	if ( ret != CS_SUCCEED ) { 
-		error = gda_error_new();
+		error = gda_connection_event_new();
 		g_return_val_if_fail (error != NULL, FALSE);
-		gda_error_set_description (error,
-															 _("an error occured when calling ct_diag attempting to retrieve a server message for recordset"));
-		gda_error_set_number (error, -1);
-		gda_error_set_source (error, "gda-sybase");
-		gda_error_set_sqlstate (error, _("Not available"));					
-		gda_connection_add_error (cnc, error);
+
+		gda_connection_event_set_description (error,
+						      _("An error occured when attempting to retrieve a server message for recordset"));
+		gda_connection_event_set_code (error, -1);
+		gda_connection_event_set_source (error, "gda-sybase");
+		gda_connection_event_set_sqlstate (error, _("Not available"));					
+		gda_connection_add_event (cnc, error);
 		return NULL;					
 	} 	
 
@@ -586,13 +587,13 @@ gda_sybase_process_msg_result(GdaConnection *cnc,
 																CS_UNUSED, 
 																NULL);   
 	if ( ret != CS_SUCCEED ) { 
-			error = gda_error_new();
+			error = gda_connection_event_new();
 			g_return_val_if_fail (error != NULL, FALSE);
-			gda_error_set_description (error, _("call to ct_diag failed when attempting to clear the server messages"));
-			gda_error_set_number (error, -1);
-			gda_error_set_source (error, "gda-sybase");
-			gda_error_set_sqlstate (error, _("Not available"));					
-			gda_connection_add_error (cnc, error);
+			gda_connection_event_set_description (error, _("call to ct_diag failed when attempting to clear the server messages"));
+			gda_connection_event_set_code (error, -1);
+			gda_connection_event_set_source (error, "gda-sybase");
+			gda_connection_event_set_sqlstate (error, _("Not available"));					
+			gda_connection_add_event (cnc, error);
 			return NULL;
 		} 	
 
